**To delete an application**

The following ``delete-application`` example deletes the specified application. ::

    aws appconfig delete-application \
    --application-id 339ohji

This command produces no output.

For more information, see `Step 1: Creating an AWS AppConfig application <https://docs.aws.amazon.com/appconfig/latest/userguide/appconfig-creating-application.html>`__ in the *AWS AppConfig User Guide*.